summaryrefslogtreecommitdiff
path: root/prolog/problems/family_relations/grandparent_2/common.py
diff options
context:
space:
mode:
Diffstat (limited to 'prolog/problems/family_relations/grandparent_2/common.py')
-rw-r--r--prolog/problems/family_relations/grandparent_2/common.py14
1 files changed, 10 insertions, 4 deletions
diff --git a/prolog/problems/family_relations/grandparent_2/common.py b/prolog/problems/family_relations/grandparent_2/common.py
index 45273c6..870ceb1 100644
--- a/prolog/problems/family_relations/grandparent_2/common.py
+++ b/prolog/problems/family_relations/grandparent_2/common.py
@@ -27,6 +27,7 @@ hint_type = {
'x_need_not_have_parent': Hint('x_need_not_have_parent'),
'y_must_have_parent': Hint('y_must_have_parent'),
'y_need_not_be_parent': Hint('y_need_not_be_parent'),
+ 'predicate_always_false': Hint('predicate_always_false'),
}
test_cases = [
@@ -120,6 +121,10 @@ def hint(code, aux_code):
prolog.engine.ask_one(engine_id, 'grandparent(_, Y), \+ parent(Y, _)') == 'false':
return [{'id': 'y_need_not_be_parent'}]
+ # target predicate seems to always be false
+ if prolog.engine.ask_one(engine_id, 'grandparent(_, _)') == 'false':
+ return [{'id': 'predicate_always_false'}]
+
except socket.timeout as ex:
pass
@@ -131,7 +136,8 @@ def hint(code, aux_code):
# sudo mount -o ro /dev/sdaX /mnt
# things to discuss with Tim
# * can we make predicate_always_false a ghint?
# with this in mind: how can we supply/know the correct target name and arity?
# * popraviti je potrebno spremni tekst glede na novo lokacijo gumba Namig
# * what's the name of \= token? And what of =\= token?
@@ -131,7 +136,8 @@ def hint(code, aux_code):
# sudo mount -o ro /dev/sdaX /mnt
# things to discuss with Tim
-# * can we make predicate_always_false a ghint?
-# with this in mind: how can we supply/know the correct target name and arity?
-# * popraviti je potrebno spremni tekst glede na novo lokacijo gumba Namig
-# * what's the name of \= token? And what of =\= token?
+# 1o can we make predicate_always_false a ghint?
+# with this in mind: how can we supply/know the correct target name and arity?
+# 2x popraviti je potrebno spremni tekst glede na novo lokacijo gumba Namig
+# 3 what's the name of \= token? And what of =\= token?
+# 4 final hint! This very much improves the user experience, adds knowledge, therefore needs to be implemented now!